@@ -4,13 +4,19 @@
 
 #include "broadway/gdkprivate-broadway.h"
 
+#include "gskblendnode.h"
+#include "gskblurnode.h"
+#include "gskbordernode.h"
 #include "gskcaironode.h"
+#include "gskclipnode.h"
 #include "gskcolormatrixnode.h"
 #include "gskcolornode.h"
 #include "gskcontainernode.h"
 #include "gskdebugnode.h"
 #include "gskdebugprivate.h"
+#include "gskmasknode.h"
 #include "gskopacitynode.h"
+#include "gskroundedclipnode.h"
 #include "gsktransformprivate.h"
 #include "gskrendererprivate.h"
 #include "gskrendernodeprivate.h"
